[−][src]Struct linuxcnc_hal::HalComponent
HAL component
An initialised HAL component ready for use in the main component loop.
Use HalComponentBuilder::new to create a new component builder. Once all pins are registered,
calling .ready() on the builder will convert it to a HalComponent ready for use in the main
loop.
Methods
impl HalComponent[src]
pub fn id(&self) -> i32[src]
Get the HAL-assigned ID for this component
pub fn name(&self) -> &str[src]
Get the component name
pub fn should_exit(&self) -> bool[src]
Check whether the component was signalled to shut down